==> MediaWikiLanguageExtensionBundle-2016.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesCu.php <==
<?php

$languageNames = array(
	'ar' => 'а҆ра́вскїй',
	'be' => 'бѣлорꙋ́сскїй',
	'cu' => 'церковнослове́нскїй',
	'de' => 'нѣме́цкїй',
	'de-at' => 'а҆ѵстрі́йскїй нѣме́цкїй',
	'de-ch' => 'є҆лветі́йскїй нѣме́цкїй',
	'en' => 'а҆нглі́йскїй',
	'en-au' => 'а҆ѵстралі́йскїй а҆нглі́йскїй',
	'en-ca' => 'кана́дскїй а҆нглі́йскїй',
	'en-gb' => 'брїта́нскїй а҆нглі́йскїй',
	'en-us' => 'а҆мерїка́нскїй а҆нглі́йскїй',
	'es' => 'і҆спа́нскїй',
	'es-419' => 'латїноамерїка́нскїй і҆спа́нскїй',
	'es-es' => 'є҆ѵрѡпе́йскїй і҆спа́нскїй',
	'es-mx' => 'і҆спанскїй (ме́ѯїка)',
	'fr' => 'францꙋ́зскїй',
	'fr-ca' => 'кана́дскїй францꙋ́зскїй',
	'fr-ch' => 'є҆лветі́йскїй францꙋ́зскїй',
	'it' => 'і҆талїа́нскїй',
	'ja' => 'ꙗ҆пѡ́нскїй',
	'kk' => 'каза́хскїй',
	'pt' => 'портога́льскїй',
	'pt-br' => 'бразі́льскїй портога́льскїй',
	'pt-pt' => 'є҆ѵрѡпе́йскїй портога́льскїй',
	'ro' => 'дакорꙋмы́нскїй',
	'ro-md' => 'молда́вскїй',
	'ru' => 'рꙋ́сскїй',
	'uk' => 'ᲂу҆краи́нскїй',
	'und' => 'невѣ́домый ѧ҆зы́къ',
	'zh' => 'хи́нскїй',
	'zh-hans' => 'ᲂу҆проще́нный хи́нскїй',
	'zh-hant' => 'традїцїо́нный хи́нскїй',
);

$currencyNames = array(
	'BRL' => 'бразі́льскїй реа́лъ',
	'BYR' => 'бѣлорꙋ́сскїй рꙋ́бль',
	'CNY' => 'хи́нскїй ю҆а́нь',
	'EUR' => 'є҆́ѵрѡ',
	'GBP' => 'а҆нглі́йскїй фꙋ́нтъ сте́рлингѡвъ',
	'INR' => 'і҆нді́йскаѧ рꙋ́пїѧ',
	'JPY' => 'ꙗ҆пѡ́нскаѧ і҆е́на',
	'KGS' => 'кирги́зскїй сꙋ́мъ',
	'KZT' => 'каза́хскаѧ деньга̀',
	'RUB' => 'рѡссі́йскїй рꙋ́бль',
	'UAH' => 'ᲂу҆краи́нскаѧ гри́вна',
	'USD' => 'а҆мерїка́нскїй до́лларъ',
	'XXX' => 'невѣ́домое пла́тное сре́дство',
);

$currencySymbols = array(
	'BRL' => 'R$',
	'BYR' => 'BYR',
	'CNY' => 'CN¥',
	'EUR' => '€',
	'GBP' => '£',
	'INR' => '₹',
	'JPY' => 'JP¥',
	'KGS' => 'KGS',
	'KZT' => '₸',
	'RUB' => '₽',
	'UAH' => '₴',
	'USD' => '$',
);

$countryNames = array(
	'AU' => 'А҆ѵстралі́ѧ',
	'BR' => 'бразі́лїа',
	'BY' => 'бѣ́лаѧ рꙋ́сь',
	'CA' => 'Кана́да',
	'CN' => 'хи́нскаѧ страна̀',
	'DE' => 'герма́нїа',
	'DK' => 'Дані́ѧ',
	'FR' => 'га́ллїа',
	'GB' => 'Вели́каѧ брїта́нїа',
	'IN' => 'і҆́ндїа',
	'IT' => 'і҆та́лїа',
	'JP' => 'ꙗ҆пѡ́нїа',
	'KG' => 'кирги́зїа',
	'KZ' => 'казахста́нъ',
	'MX' => 'Ме́ѯїко',
	'RU' => 'рѡссі́а',
	'UA' => 'ᲂу҆краи́на',
	'US' => 'а҆мерїка̑нскїѧ соедине̑нныѧ держа̑вы',
);

==> MediaWikiLanguageExtensionBundle-2016.04.tar.bz2: extensions/cldr/CldrNames/CldrNamesCu.php <==
<?php

$languageNames = [
	'ar' => 'а҆ра́вскїй',
	'be' => 'бѣлорꙋ́сскїй',
	'cu' => 'церковнослове́нскїй',
	'de' => 'нѣме́цкїй',
	'de-at' => 'а҆ѵстрі́йскїй нѣме́цкїй',
	'de-ch' => 'є҆лветі́йскїй нѣме́цкїй',
	'en' => 'а҆нглі́йскїй',
	'en-au' => 'а҆ѵстралі́йскїй а҆нглі́йскїй',
	'en-ca' => 'кана́дскїй а҆нглі́йскїй',
	'en-gb' => 'брїта́нскїй а҆нглі́йскїй',
	'en-us' => 'а҆мерїка́нскїй а҆нглі́йскїй',
	'es' => 'і҆спа́нскїй',
	'es-419' => 'латїноамерїка́нскїй і҆спа́нскїй',
	'es-es' => 'є҆ѵрѡпе́йскїй і҆спа́нскїй',
	'es-mx' => 'і҆спанскїй (ме́ѯїка)',
	'fr' => 'францꙋ́зскїй',
	'fr-ca' => 'кана́дскїй францꙋ́зскїй',
	'fr-ch' => 'є҆лветі́йскїй францꙋ́зскїй',
	'it' => 'і҆талїа́нскїй',
	'ja' => 'ꙗ҆пѡ́нскїй',
	'kk' => 'каза́хскїй',
	'pt' => 'портога́льскїй',
	'pt-br' => 'бразі́льскїй портога́льскїй',
	'pt-pt' => 'є҆ѵрѡпе́йскїй портога́льскїй',
	'ro' => 'дакорꙋмы́нскїй',
	'ro-md' => 'молда́вскїй',
	'ru' => 'рꙋ́сскїй',
	'uk' => 'ᲂу҆краи́нскїй',
	'und' => 'невѣ́домый ѧ҆зы́къ',
	'zh' => 'хи́нскїй',
	'zh-hans' => 'ᲂу҆проще́нный хи́нскїй',
	'zh-hant' => 'традїцїо́нный хи́нскїй',
];

$currencyNames = [
	'BRL' => 'бразі́льскїй реа́лъ',
	'BYR' => 'бѣлорꙋ́сскїй рꙋ́бль',
	'CNY' => 'хи́нскїй ю҆а́нь',
	'EUR' => 'є҆́ѵрѡ',
	'GBP' => 'а҆нглі́йскїй фꙋ́нтъ сте́рлингѡвъ',
	'INR' => 'і҆нді́йскаѧ рꙋ́пїѧ',
	'JPY' => 'ꙗ҆пѡ́нскаѧ і҆е́на',
	'KGS' => 'кирги́зскїй сꙋ́мъ',
	'KZT' => 'каза́хскаѧ деньга̀',
	'RUB' => 'рѡссі́йскїй рꙋ́бль',
	'UAH' => 'ᲂу҆краи́нскаѧ гри́вна',
	'USD' => 'а҆мерїка́нскїй до́лларъ',
	'XXX' => 'невѣ́домое пла́тное сре́дство',
];

$currencySymbols = [
	'BRL' => 'R$',
	'BYR' => 'BYR',
	'CNY' => 'CN¥',
	'EUR' => '€',
	'GBP' => '£',
	'INR' => '₹',
	'JPY' => 'JP¥',
	'KGS' => 'KGS',
	'KZT' => '₸',
	'RUB' => '₽',
	'UAH' => '₴',
	'USD' => '$',
];

$countryNames = [
	'AU' => 'А҆ѵстралі́ѧ',
	'BR' => 'бразі́лїа',
	'BY' => 'бѣ́лаѧ рꙋ́сь',
	'CA' => 'Кана́да',
	'CN' => 'хи́нскаѧ страна̀',
	'DE' => 'герма́нїа',
	'DK' => 'Дані́ѧ',
	'FR' => 'га́ллїа',
	'GB' => 'Вели́каѧ брїта́нїа',
	'IN' => 'і҆́ндїа',
	'IT' => 'і҆та́лїа',
	'JP' => 'ꙗ҆пѡ́нїа',
	'KG' => 'кирги́зїа',
	'KZ' => 'казахста́нъ',
	'MX' => 'Ме́ѯїко',
	'RU' => 'рѡссі́а',
	'UA' => 'ᲂу҆краи́на',
	'US' => 'а҆мерїка̑нскїѧ соедине̑нныѧ держа̑вы',
];
